@@ -171,7 +171,7 @@ class DropConstraintOp(MigrateOperation):
             sqla_compat.constraint_name_or_none(constraint.name),
             constraint_table.name,
             schema=constraint_table.schema,
-            type_=types[constraint.__visit_name__],
+            type_=types.get(constraint.__visit_name__),
             _reverse=AddConstraintOp.from_constraint(constraint),
         )
 
@@ -545,6 +545,8 @@ class CreateForeignKeyOp(AddConstraintOp):
             kw["deferrable"] = fk_constraint.deferrable
         if fk_constraint.use_alter:
             kw["use_alter"] = fk_constraint.use_alter
+        if fk_constraint.match:
+            kw["match"] = fk_constraint.match
 
         (
             source_schema,
