@@ -480,12 +480,25 @@ class AutogenRenderTest(TestBase):
             "initially='XYZ')",
         )
 
+        fk = ForeignKeyConstraint([t1.c.c], [t2.c.c_rem], match="FULL")
+        op_obj = ops.AddConstraintOp.from_constraint(fk)
+        eq_ignore_whitespace(
+            re.sub(
+                r"u'",
+                "'",
+                autogenerate.render_op_text(self.autogen_context, op_obj),
+            ),
+            "op.create_foreign_key(None, 't', 't2', ['c'], ['c_rem'], "
+            "match='FULL')",
+        )
+
         fk = ForeignKeyConstraint(
             [t1.c.c],
             [t2.c.c_rem],
             initially="XYZ",
             ondelete="CASCADE",
             deferrable=True,
+            match="FULL",
         )
         op_obj = ops.AddConstraintOp.from_constraint(fk)
         eq_ignore_whitespace(
@@ -495,7 +508,8 @@ class AutogenRenderTest(TestBase):
                 autogenerate.render_op_text(self.autogen_context, op_obj),
             ),
             "op.create_foreign_key(None, 't', 't2', ['c'], ['c_rem'], "
-            "ondelete='CASCADE', initially='XYZ', deferrable=True)",
+            "ondelete='CASCADE', initially='XYZ', deferrable=True, "
+            "match='FULL')",
         )
 
     def test_add_fk_constraint_inline_colkeys(self):
@@ -1374,12 +1388,25 @@ class AutogenRenderTest(TestBase):
             "sa.ForeignKeyConstraint(['c'], ['t2.c_rem'], initially='XYZ')",
         )
 
+        fk = ForeignKeyConstraint([t1.c.c], [t2.c.c_rem], match="FULL")
+        eq_ignore_whitespace(
+            re.sub(
+                r"u'",
+                "'",
+                autogenerate.render._render_constraint(
+                    fk, self.autogen_context, m
+                ),
+            ),
+            "sa.ForeignKeyConstraint(['c'], ['t2.c_rem'], match='FULL')",
+        )
+
         fk = ForeignKeyConstraint(
             [t1.c.c],
             [t2.c.c_rem],
             initially="XYZ",
             ondelete="CASCADE",
             deferrable=True,
+            match="FULL",
         )
         eq_ignore_whitespace(
             re.sub(
@@ -1390,7 +1417,8 @@ class AutogenRenderTest(TestBase):
                 ),
             ),
             "sa.ForeignKeyConstraint(['c'], ['t2.c_rem'], "
-            "ondelete='CASCADE', initially='XYZ', deferrable=True)",
+            "ondelete='CASCADE', initially='XYZ', deferrable=True, "
+            "match='FULL')",
         )
 
     def test_render_fk_constraint_resolve_key(self):
